<li class="model story <%= mark_if_closed(story) %> tracker<%= story ? story.tracker_id : '' %>" id="<%= story_html_id_or_empty(story) %>">
  <div class="id story_tooltip story_field" title="<%= render :partial => "rb_stories/tooltip", :object => story %>">
    <div class="t"><%= issue_link_or_empty(story) %></div>
    <div class="v"><%= id_or_empty(story) %></div>
  </div>
  <div class="tracker_id editable story_field" fieldtype="select" fieldname="tracker_id" fieldlabel="<%=l(:field_tracker_id)%>">
    <div class="t"><%= tracker_name_or_empty(story) %></div>
    <div class="v"><%= tracker_id_or_empty(story) %></div>
  </div>
  <div class="subject editable story_field" fieldname="subject" fieldlabel="<%=l(:field_subject)%>" fieldtype="textarea"><%=h story.subject %></div>
  <div class="status_id editable story_field" fieldtype="select" fieldname="status_id" fieldlabel="<%=l(:field_status_id)%>">
    <div class="t"><%= status_label_or_default(story) %></div>
    <div class="v"><%= status_id_or_default(story) %></div>
  </div>
  <% if Setting.plugin_redmine_backlogs[:story_points].blank? %>
  <div class="story_points editable story_points_text" fieldname="story_points" fieldlabel="<%=l(:story_points)%>" fieldtype="input"><%= story_points_or_empty(story) %></div>
  <% else %>
  <div class="story_points editable story_points_select" fieldtype="select" fieldname="story_points" fieldlabel="<%=l(:story_points)%>">
    <% %w(t v).each do |c| %>
      <div class="<%=h c %>"><%= story_points_or_empty(story) %></div>
    <% end %>
  </div>
  <% end %>
  <div class="fixed_version_id"><%= story.fixed_version_id %></div>
  <div class="user_status"><%= story.author == User.current ? '+' : '-' %>c<%= story.assigned_to == User.current ? '+' : '-' %>a</div>
  <div class="higher_item_id"><%= story.higher_item.blank? ? '' : story.higher_item.id %></div>
  <div class="meta">
    <%= render :partial => "shared/model_errors", :object => story.errors %>
  </div>
  <div class="clearfix"></div>
</li>
